@@ -22,6 +22,65 @@
 #include "client.h"
 #include "../log.h"
 
+static int
+cmd_faststart(struct lldpctl_conn_t *conn, struct writer *w, struct cmd_env *env,
+    const void *arg)
+{
+	log_debug("lldpctl", "configure fast interval support");
+
+	lldpctl_atom_t *config = lldpctl_get_configuration(conn);
+	if (config == NULL) {
+		log_warnx("lldpctl", "unable to get configuration from lldpd. %s",
+		    lldpctl_last_strerror(conn));
+		return 0;
+	}
+
+	const char *action = arg;
+	if ((!strcmp(action, "enable") &&
+		(lldpctl_atom_set_int(config, lldpctl_k_config_fast_start_enabled, 1) ==
+		    NULL)) ||
+	    (!strcmp(action, "disable") &&
+		(lldpctl_atom_set_int(config, lldpctl_k_config_fast_start_enabled, 0) ==
+		    NULL)) ||
+	    (!strcmp(action, "delay") &&
+		(lldpctl_atom_set_str(config, lldpctl_k_config_fast_start_interval,
+		     cmdenv_get(env, "tx-interval")) == NULL))) {
+		log_warnx("lldpctl", "unable to setup fast start. %s",
+		    lldpctl_last_strerror(conn));
+		lldpctl_atom_dec_ref(config);
+		return 0;
+	}
+	log_info("lldpctl", "configuration for fast start applied");
+	lldpctl_atom_dec_ref(config);
+	return 1;
+}
+
+void
+register_commands_faststart(struct cmd_node *configure_lldp, struct cmd_node *unconfigure_lldp)
+{
+	struct cmd_node *configure_fast = commands_new(configure_lldp, "fast-start",
+	    "Fast start configuration", cmd_check_no_env, NULL, "ports");
+	struct cmd_node *unconfigure_fast = commands_new(unconfigure_lldp, "fast-start",
+	    "Fast start configuration", cmd_check_no_env, NULL, "ports");
+
+	/* Enable */
+	commands_new(commands_new(configure_fast, "enable", "Enable fast start", NULL,
+			 NULL, NULL),
+	    NEWLINE, "Enable fast start", NULL, cmd_faststart, "enable");
+
+	/* Set TX delay */
+	commands_new(commands_new(commands_new(configure_fast, "tx-interval",
+				      "Set LLDP fast transmit delay", NULL, NULL, NULL),
+			 NULL, "LLDP fast transmit delay in seconds", NULL,
+			 cmd_store_env_value, "tx-interval"),
+	    NEWLINE, "Set LLDP fast transmit delay", NULL, cmd_faststart, "delay");
+
+	/* Disable */
+	commands_new(commands_new(unconfigure_fast, NEWLINE, "Disable fast start", NULL,
+			 cmd_faststart, "disable"),
+	    NEWLINE, "Disable fast start", NULL, cmd_faststart, "disable");
+}
+
 static int
 cmd_txdelay(struct lldpctl_conn_t *conn, struct writer *w, struct cmd_env *env,
     const void *arg)
@@ -413,6 +472,52 @@ cmd_vlan_tx(struct lldpctl_conn_t *conn, struct writer *w, struct cmd_env *env,
 	return 1;
 }
 
+static int
+cmd_set_vlan_pattern(struct lldpctl_conn_t *conn, struct writer *w, struct cmd_env *env,
+    const void *arg)
+{
+	lldpctl_atom_t *port;
+	const char *name;
+
+	const char *value = cmdenv_get(env, "vlan-pattern");
+	
+	log_info("lldpctl", "VLAN pattern set to new value %s",value ? value : "(none)");
+
+	while ((port = cmd_iterate_on_ports(conn, env, &name))) {
+		if (lldpctl_atom_set_str(port, lldpctl_k_port_vlan_advertise_pattern, value) ==
+			NULL) {
+			log_warnx("lldpctl",
+				"unable to set VLAN pattern config on %s."
+				" %s",
+				name, lldpctl_last_strerror(conn));
+		}
+	}
+
+	return 1;
+}
+
+static int
+cmd_unset_vlan_pattern(struct lldpctl_conn_t *conn, struct writer *w, struct cmd_env *env,
+    const void *arg)
+{
+	log_debug("lldpctl", "unset VLAN pattern");
+	lldpctl_atom_t *port;
+	const char *name;
+
+	while ((port = cmd_iterate_on_ports(conn, env, &name))) {
+		if (lldpctl_atom_set_str(port, lldpctl_k_port_vlan_advertise_pattern, "*") ==
+			NULL) {
+			log_warnx("lldpctl",
+				"unable to set VLAN pattern config on %s."
+				" %s",
+				name, lldpctl_last_strerror(conn));
+		}
+	}
+
+	return 1;
+}
+
+
 #ifdef ENABLE_CUSTOM
 static int
 cmd_custom_tlv_set(struct lldpctl_conn_t *conn, struct writer *w, struct cmd_env *env,
@@ -617,6 +722,8 @@ register_commands_configure_lldp(struct cmd_node *configure,
 	struct cmd_node *unconfigure_lldp =
 	    commands_new(unconfigure, "lldp", "LLDP configuration", NULL, NULL, NULL);
 
+	register_commands_faststart(configure_lldp, unconfigure_lldp);
+
 	commands_new(
 	    commands_new(commands_new(configure_lldp, "tx-interval",
 			     "Set LLDP transmit delay", cmd_check_no_env, NULL,
@@ -756,6 +863,22 @@ register_commands_configure_lldp(struct cmd_node *configure,
 	    NEWLINE, "Disable VLAN tagging of transmitted LLDP frames", NULL,
 	    cmd_vlan_tx, NULL);
 
+
+	/* Now handle vlan advertisements configuration. */
+	struct cmd_node *configure_lldp_vlan_advertisements = commands_new(configure_lldp,
+	    "vlan-advertisements", "Configure vlan address advertisements", NULL, NULL, NULL);
+	commands_new(commands_new(commands_new(configure_lldp_vlan_advertisements, "pattern",
+			"Set VLAN pattern", NULL, NULL, NULL),
+		NULL, "VLAN pattern (comma-separated list of wildcards)",
+		NULL, cmd_store_env_value, "vlan-pattern"),
+		NEWLINE, "Set active VLAN pattern", NULL, cmd_set_vlan_pattern, NULL);
+
+	struct cmd_node *unconfigure_vlan_advertisements =
+	    commands_new(unconfigure_lldp, "vlan-advertisements", "Unconfigure vlan address advertisements", NULL, NULL, NULL);	
+	commands_new(commands_new(unconfigure_vlan_advertisements, "pattern",
+		"Delete any VLAN pattern", NULL, NULL, NULL),
+		NEWLINE, "Clear VLAN pattern", NULL, cmd_unset_vlan_pattern, NULL);
+
 #ifdef ENABLE_CUSTOM
 	register_commands_configure_lldp_custom_tlvs(configure_lldp, unconfigure_lldp);
 #endif
